'use strict';

var _getIterator2 = require('babel-runtime/core-js/get-iterator');

var _getIterator3 = _interopRequireDefault(_getIterator2);

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _koa = require('koa');

var _koa2 = _interopRequireDefault(_koa);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _http = require('http');

var _http2 = _interopRequireDefault(_http);

var _koaStatic = require('koa-static');

var _koaStatic2 = _interopRequireDefault(_koaStatic);

var _koaMount = require('koa-mount');

var _koaMount2 = _interopRequireDefault(_koaMount);

var _koaCompress = require('koa-compress');

var _koaCompress2 = _interopRequireDefault(_koaCompress);

var _koaHandlebars = require('koa-handlebars');

var _koaHandlebars2 = _interopRequireDefault(_koaHandlebars);

var _koaRouter = require('koa-router');

var _koaRouter2 = _interopRequireDefault(_koaRouter);

var _koaSendfile = require('koa-sendfile');

var _koaSendfile2 = _interopRequireDefault(_koaSendfile);

var _koaBody = require('koa-body');

var _koaBody2 = _interopRequireDefault(_koaBody);

var _koaJwt = require('koa-jwt');

var _koaJwt2 = _interopRequireDefault(_koaJwt);

var _db = require('./lib/db');

var _helpers = require('./lib/helpers');

var _helpers2 = _interopRequireDefault(_helpers);

var _utils = require('./lib/utils');

var _front = require('./routes/front');

var _front2 = _interopRequireDefault(_front);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var router = (0, _koaRouter2.default)();
var app = (0, _koa2.default)();

app.use((0, _koaCompress2.default)());

router.use('/api', (0, _koaJwt2.default)({
  secret: process.env.SESSION_SECRET
}).unless({
  path: [/token-auth/, /token-refresh/, /reset-password/]
}));

router.use((0, _koaBody2.default)({
  multipart: true
}));

function getRoutes(path) {
  // Retrieve routes from passed path
  return require('./routes/' + path).routes();
}

var APIroutes = ['content', 'reset-password', 'token', 'upload'];

// Register media routes and API
router.use('/uploads*', getRoutes('uploads'));

var _iteratorNormalCompletion = true;
var _didIteratorError = false;
var _iteratorError = undefined;

try {
  for (var _iterator = (0, _getIterator3.default)(APIroutes), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
    var route = _step.value;

    router.use('/api', getRoutes('api/' + route));
  }

  // Serve assets of admin area...
} catch (err) {
  _didIteratorError = true;
  _iteratorError = err;
} finally {
  try {
    if (!_iteratorNormalCompletion && _iterator.return) {
      _iterator.return();
    }
  } finally {
    if (_didIteratorError) {
      throw _iteratorError;
    }
  }
}

app.use((0, _koaMount2.default)('/admin', (0, _koaStatic2.default)(__dirname + '/client')));

// ...and the Ember app
router.get('/admin*', _regenerator2.default.mark(function _callee() {
  return _regenerator2.default.wrap(function _callee$(_context) {
    while (1) {
      switch (_context.prev = _context.next) {
        case 0:
          return _context.delegateYield(_koaSendfile2.default.call(this, __dirname + '/client/index.html'), 't0', 1);

        case 1:
          if (!this.status) this.throw(404);

        case 2:
        case 'end':
          return _context.stop();
      }
    }
  }, _callee, this);
}));

// Serve frontend assets
app.use((0, _koaMount2.default)('/assets', (0, _koaStatic2.default)(process.cwd() + '/dist')));

router.get('/login', _regenerator2.default.mark(function _callee2(next) {
  return _regenerator2.default.wrap(function _callee2$(_context2) {
    while (1) {
      switch (_context2.prev = _context2.next) {
        case 0:
          _context2.next = 2;
          return next;

        case 2:
          this.redirect('/admin/login');

        case 3:
        case 'end':
          return _context2.stop();
      }
    }
  }, _callee2, this);
}));

// Log HTTP requests to console
app.use(_regenerator2.default.mark(function _callee3(next) {
  var start, ms;
  return _regenerator2.default.wrap(function _callee3$(_context3) {
    while (1) {
      switch (_context3.prev = _context3.next) {
        case 0:
          start = new Date();
          _context3.next = 3;
          return next;

        case 3:
          ms = new Date() - start;

          if (!(this.url.split('/')[1] == 'api')) {
            _context3.next = 6;
            break;
          }

          return _context3.abrupt('return');

        case 6:

          console.log(_chalk2.default.blue('[muffin]') + ' %s %s - %sms', this.method, this.url, ms);

        case 7:
        case 'end':
          return _context3.stop();
      }
    }
  }, _callee3, this);
}));

// Load front routes


// Enable new instance of rendering engine for front
_front2.default.use((0, _koaHandlebars2.default)({
  cache: app.env !== 'development',
  root: process.cwd() + '/views',
  layoutsDir: '../layouts',
  viewsDir: '/',
  defaultLayout: 'default',
  helpers: _helpers2.default
}));

app.router = _front2.default;

app.run = function (frontRouter) {
  // Register front routes
  router.use('/', frontRouter.routes());
  router.use('/', frontRouter.allowedMethods());

  // Register dashboard routes
  app.use(router.routes());
  app.use(router.allowedMethods());

  app.listen(process.env.PORT || 2000, function () {
    var port = this.address().port;
    var host = 'localhost';
    var url = 'http://' + host + ':' + port;

    // Output message as soon as server is running
    console.log(_chalk2.default.blue('[muffin]') + ' ' + 'Running at ' + _chalk2.default.grey(url));
  });
};

module.exports = app;