'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.fs = exports.goose = exports.rope = undefined;

var _mongoose = require('mongoose');

var _mongoose2 = _interopRequireDefault(_mongoose);

var _gridfsStream = require('gridfs-stream');

var _gridfsStream2 = _interopRequireDefault(_gridfsStream);

var _utils = require('./utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var dbHost = process.env.DB_HOST || 'localhost';
var dbName = process.env.DB_NAME || 'muffin';

// Connect to DB using the credentials set in the ".env" file
_mongoose2.default.connect('mongodb://' + dbHost + '/' + dbName, {
  user: process.env.DB_USER,
  pass: process.env.DB_PASSWORD
});

var connection = _mongoose2.default.connection;

connection.on('error', function (info) {
  if (info.message.includes('ECONNREFUSED')) {
    info.message = 'Please make sure it\'s running and accessible!';
  }

  (0, _utils.log)('Couldn\'t connect to DB: ' + info.message);
  process.exit(1);
});

process.on('SIGINT', function () {
  return connection.close(function () {
    process.exit(0);
  });
});

exports.rope = connection;
exports.goose = _mongoose2.default;

// Tell gridfs where to find the files

_gridfsStream2.default.mongo = _mongoose2.default.mongo;
var gridConnection = (0, _gridfsStream2.default)(connection.db);

exports.fs = gridConnection;